Re: [RFC v2 03/18] target/i386: sev: Rename QSevGuestInfo

2020-06-01 Thread Richard Henderson
On 5/20/20 8:42 PM, David Gibson wrote:
> At the moment this is a purely passive object which is just a container for
> information used elsewhere, hence the name.  I'm going to change that
> though, so as a preliminary rename it to SevGuestState.
> 
> That name risks confusion with both SEVState and SevState, but I'll be
> working on that in following patches.
> 
> Signed-off-by: David Gibson 
> ---
>  target/i386/sev.c | 87 ---
>  1 file changed, 44 insertions(+), 43 deletions(-)

Reviewed-by: Richard Henderson 

r~




Re: [RFC v2 03/18] target/i386: sev: Rename QSevGuestInfo

2020-05-29 Thread Philippe Mathieu-Daudé
On 5/21/20 5:42 AM, David Gibson wrote:
> At the moment this is a purely passive object which is just a container for
> information used elsewhere, hence the name.  I'm going to change that
> though, so as a preliminary rename it to SevGuestState.
> 
> That name risks confusion with both SEVState and SevState, but I'll be
> working on that in following patches.
> 
> Signed-off-by: David Gibson 
> ---
>  target/i386/sev.c | 87 ---
>  1 file changed, 44 insertions(+), 43 deletions(-)

Reviewed-by: Philippe Mathieu-Daudé 




[RFC v2 03/18] target/i386: sev: Rename QSevGuestInfo

2020-05-20 Thread David Gibson
At the moment this is a purely passive object which is just a container for
information used elsewhere, hence the name.  I'm going to change that
though, so as a preliminary rename it to SevGuestState.

That name risks confusion with both SEVState and SevState, but I'll be
working on that in following patches.

Signed-off-by: David Gibson 
---
 target/i386/sev.c | 87 ---
 1 file changed, 44 insertions(+), 43 deletions(-)

diff --git a/target/i386/sev.c b/target/i386/sev.c
index 53def5f41a..b6ed719fb5 100644
--- a/target/i386/sev.c
+++ b/target/i386/sev.c
@@ -29,22 +29,23 @@
 #include "trace.h"
 #include "migration/blocker.h"
 
-#define TYPE_QSEV_GUEST_INFO "sev-guest"
-#define QSEV_GUEST_INFO(obj)  \
-OBJECT_CHECK(QSevGuestInfo, (obj), TYPE_QSEV_GUEST_INFO)
+#define TYPE_SEV_GUEST "sev-guest"
+#define SEV_GUEST(obj)  \
+OBJECT_CHECK(SevGuestState, (obj), TYPE_SEV_GUEST)
 
-typedef struct QSevGuestInfo QSevGuestInfo;
+typedef struct SevGuestState SevGuestState;
 
 /**
- * QSevGuestInfo:
+ * SevGuestState:
  *
  * The QSevGuestInfo object is used for creating a SEV guest.
  *
  * # $QEMU \
  * -object sev-guest,id=sev0 \
  * -machine ...,memory-encryption=sev0
  */
-struct QSevGuestInfo {
+struct SevGuestState {
 Object parent_obj;
 
 char *sev_device;
@@ -57,7 +58,7 @@ struct QSevGuestInfo {
 };
 
 struct SEVState {
-QSevGuestInfo *sev_info;
+SevGuestState *sev_info;
 uint8_t api_major;
 uint8_t api_minor;
 uint8_t build_id;
@@ -235,82 +236,82 @@ static struct RAMBlockNotifier sev_ram_notifier = {
 };
 
 static void
-qsev_guest_finalize(Object *obj)
+sev_guest_finalize(Object *obj)
 {
 }
 
 static char *
-qsev_guest_get_session_file(Object *obj, Error **errp)
+sev_guest_get_session_file(Object *obj, Error **errp)
 {
-QSevGuestInfo *s = QSEV_GUEST_INFO(obj);
+SevGuestState *s = SEV_GUEST(obj);
 
 return s->session_file ? g_strdup(s->session_file) : NULL;
 }
 
 static void
-qsev_guest_set_session_file(Object *obj, const char *value, Error **errp)
+sev_guest_set_session_file(Object *obj, const char *value, Error **errp)
 {
-QSevGuestInfo *s = QSEV_GUEST_INFO(obj);
+SevGuestState *s = SEV_GUEST(obj);
 
 s->session_file = g_strdup(value);
 }
 
 static char *
-qsev_guest_get_dh_cert_file(Object *obj, Error **errp)
+sev_guest_get_dh_cert_file(Object *obj, Error **errp)
 {
-QSevGuestInfo *s = QSEV_GUEST_INFO(obj);
+SevGuestState *s = SEV_GUEST(obj);
 
 return g_strdup(s->dh_cert_file);
 }
 
 static void
-qsev_guest_set_dh_cert_file(Object *obj, const char *value, Error **errp)
+sev_guest_set_dh_cert_file(Object *obj, const char *value, Error **errp)
 {
-QSevGuestInfo *s = QSEV_GUEST_INFO(obj);
+SevGuestState *s = SEV_GUEST(obj);
 
 s->dh_cert_file = g_strdup(value);
 }
 
 static char *
-qsev_guest_get_sev_device(Object *obj, Error **errp)
+sev_guest_get_sev_device(Object *obj, Error **errp)
 {
-QSevGuestInfo *sev = QSEV_GUEST_INFO(obj);
+SevGuestState *sev = SEV_GUEST(obj);
 
 return g_strdup(sev->sev_device);
 }
 
 static void
-qsev_guest_set_sev_device(Object *obj, const char *value, Error **errp)
+sev_guest_set_sev_device(Object *obj, const char *value, Error **errp)
 {
-QSevGuestInfo *sev = QSEV_GUEST_INFO(obj);
+SevGuestState *sev = SEV_GUEST(obj);
 
 sev->sev_device = g_strdup(value);
 }
 
 static void
-qsev_guest_class_init(ObjectClass *oc, void *data)
+sev_guest_class_init(ObjectClass *oc, void *data)
 {
 object_class_property_add_str(oc, "sev-device",
-  qsev_guest_get_sev_device,
-  qsev_guest_set_sev_device);
+  sev_guest_get_sev_device,
+  sev_guest_set_sev_device);
 object_class_property_set_description(oc, "sev-device",
 "SEV device to use");
 object_class_property_add_str(oc, "dh-cert-file",
-  qsev_guest_get_dh_cert_file,
-  qsev_guest_set_dh_cert_file);
+  sev_guest_get_dh_cert_file,
+  sev_guest_set_dh_cert_file);
 object_class_property_set_description(oc, "dh-cert-file",
 "guest owners DH certificate (encoded with base64)");
 object_class_property_add_str(oc, "session-file",
-  qsev_guest_get_session_file,
-  qsev_guest_set_session_file);
+  sev_guest_get_session_file,
+  sev_guest_set_session_file);
 object_class_property_set_description(oc, "session-file",
 "guest owners session parameters (encoded with base64)");
 }
 
 static void
-qsev_guest_init(Object
@@ -29,22 +29,23 @@
  *
- * The QSevGuestInfo object is used for creating a SEV guest.
+ * The SevGuestState object is used for creating and managing a SEV
+ * guest.
  *
  * # $QEMU \